@@ -8,6 +8,7 @@
 
 const char* ffDetectCamera(FFlist* result)
 {
+    #ifdef MAC_OS_X_VERSION_10_15
     FF_SUPPRESS_IO(); // #822
 
     AVCaptureDeviceType deviceType;
@@ -47,6 +48,8 @@ const char* ffDetectCamera(FFlist* result)
         camera->width = size.width < 0 ? 0 : (uint32_t) size.width;
         camera->height = size.height < 0 ? 0 : (uint32_t) size.height;
     }
-
     return NULL;
+    #else
+    return "No support for old MacOS version";
+    #endif
 }
